---
title: Higher Laws
id: higher-laws
layout: default.haml
author: Henry David Thoreau
date: 2018-04-15
chapter: 11
kind: article
---

## Higher Laws

As I came home through the woods with my string of fish, trailing my
pole, it being now quite dark, I caught a glimpse of a woodchuck
stealing across my path, and felt a strange thrill of savage delight,
and was strongly tempted to seize and devour him raw; not that I was
hungry then, except for that wildness which he represented. Once or
twice, however, while I lived at the pond, I found myself ranging the
woods, like a half-starved hound, with a strange abandonment, seeking
some kind of venison which I might devour, and no morsel could have
been too savage for me. The wildest scenes had become unaccountably
familiar. I found in myself, and still find, an instinct toward a
higher, or, as it is named, spiritual life, as do most men, and another
toward a primitive rank and savage one, and I reverence them both. I
love the wild not less than the good. The wildness and adventure that
are in fishing still recommended it to me. I like sometimes to take
rank hold on life and spend my day more as the animals do. Perhaps I
have owed to this employment and to hunting, when quite young, my
closest acquaintance with Nature. They early introduce us to and detain
us in scenery with which otherwise, at that age, we should have little
acquaintance. Fishermen, hunters, woodchoppers, and others, spending
their lives in the fields and woods, in a peculiar sense a part of
Nature themselves, are often in a more favorable mood for observing
her, in the intervals of their pursuits, than philosophers or poets
even, who approach her with expectation. She is not afraid to exhibit
herself to them. The traveller on the prairie is naturally a hunter, on
the head waters of the Missouri and Columbia a trapper, and at the
Falls of St. Mary a fisherman. He who is only a traveller learns things
at second-hand and by the halves, and is poor authority. We are most
interested when science reports what those men already know practically
or instinctively, for that alone is a true _humanity_, or account of
human experience.

They mistake who assert that the Yankee has few amusements, because he
has not so many public holidays, and men and boys do not play so many
games as they do in England, for here the more primitive but solitary
amusements of hunting fishing and the like have not yet given place to
the former. Almost every New England boy among my contemporaries
shouldered a fowling piece between the ages of ten and fourteen; and
his hunting and fishing grounds were not limited, like the preserves of
an English nobleman, but were more boundless even than those of a
savage. No wonder, then, that he did not oftener stay to play on the
common. But already a change is taking place, owing, not to an
increased humanity, but to an increased scarcity of game, for perhaps
the hunter is the greatest friend of the animals hunted, not excepting
the Humane Society.

Moreover, when at the pond, I wished sometimes to add fish to my fare
for variety. I have actually fished from the same kind of necessity
that the first fishers did. Whatever humanity I might conjure up
against it was all factitious, and concerned my philosophy more than my
feelings. I speak of fishing only now, for I had long felt differently
about fowling, and sold my gun before I went to the woods. Not that I
am less humane than others, but I did not perceive that my feelings
were much affected. I did not pity the fishes nor the worms. This was
habit. As for fowling, during the last years that I carried a gun my
excuse was that I was studying ornithology, and sought only new or rare
birds. But I confess that I am now inclined to think that there is a
finer way of studying ornithology than this. It requires so much closer
attention to the habits of the birds, that, if for that reason only, I
have been willing to omit the gun. Yet notwithstanding the objection on
the score of humanity, I am compelled to doubt if equally valuable
sports are ever substituted for these; and when some of my friends have
asked me anxiously about their boys, whether they should let them hunt,
I have answered, yes,—remembering that it was one of the best parts of
my education,—_make_ them hunters, though sportsmen only at first, if
possible, mighty hunters at last, so that they shall not find game
large enough for them in this or any vegetable wilderness,—hunters as
well as fishers of men. Thus far I am of the opinion of Chaucer’s nun,
who

     “yave not of the text a pulled hen
     That saith that hunters ben not holy men.”

There is a period in the history of the individual, as of the race,
when the hunters are the “best men,” as the Algonquins called them. We
cannot but pity the boy who has never fired a gun; he is no more
humane, while his education has been sadly neglected. This was my
answer with respect to those youths who were bent on this pursuit,
trusting that they would soon outgrow it. No humane being, past the
thoughtless age of boyhood, will wantonly murder any creature which
holds its life by the same tenure that he does. The hare in its
extremity cries like a child. I warn you, mothers, that my sympathies
do not always make the usual phil-_anthropic_ distinctions.

Such is oftenest the young man’s introduction to the forest, and the
most original part of himself. He goes thither at first as a hunter and
fisher, until at last, if he has the seeds of a better life in him, he
distinguishes his proper objects, as a poet or naturalist it may be,
and leaves the gun and fish-pole behind. The mass of men are still and
always young in this respect. In some countries a hunting parson is no
uncommon sight. Such a one might make a good shepherd’s dog, but is far
from being the Good Shepherd. I have been surprised to consider that
the only obvious employment, except wood-chopping, ice-cutting, or the
like business, which ever to my knowledge detained at Walden Pond for a
whole half day any of my fellow-citizens, whether fathers or children
of the town, with just one exception, was fishing. Commonly they did
not think that they were lucky, or well paid for their time, unless
they got a long string of fish, though they had the opportunity of
seeing the pond all the while. They might go there a thousand times
before the sediment of fishing would sink to the bottom and leave their
purpose pure; but no doubt such a clarifying process would be going on
all the while. The governor and his council faintly remember the pond,
for they went a-fishing there when they were boys; but now they are too
old and dignified to go a-fishing, and so they know it no more forever.
Yet even they expect to go to heaven at last. If the legislature
regards it, it is chiefly to regulate the number of hooks to be used
there; but they know nothing about the hook of hooks with which to
angle for the pond itself, impaling the legislature for a bait. Thus,
even in civilized communities, the embryo man passes through the hunter
stage of development.

I have found repeatedly, of late years, that I cannot fish without
falling a little in self-respect. I have tried it again and again. I
have skill at it, and, like many of my fellows, a certain instinct for
it, which revives from time to time, but always when I have done I feel
that it would have been better if I had not fished. I think that I do
not mistake. It is a faint intimation, yet so are the first streaks of
morning. There is unquestionably this instinct in me which belongs to
the lower orders of creation; yet with every year I am less a
fisherman, though without more humanity or even wisdom; at present I am
no fisherman at all. But I see that if I were to live in a wilderness I
should again be tempted to become a fisher and hunter in earnest.
Beside, there is something essentially unclean about this diet and all
flesh, and I began to see where housework commences, and whence the
endeavor, which costs so much, to wear a tidy and respectable
appearance each day, to keep the house sweet and free from all ill
odors and sights. Having been my own butcher and scullion and cook, as
well as the gentleman for whom the dishes were served up, I can speak
from an unusually complete experience. The practical objection to
animal food in my case was its uncleanness; and, besides, when I had
caught and cleaned and cooked and eaten my fish, they seemed not to
have fed me essentially. It was insignificant and unnecessary, and cost
more than it came to. A little bread or a few potatoes would have done
as well, with less trouble and filth. Like many of my contemporaries, I
had rarely for many years used animal food, or tea, or coffee, &c.; not
so much because of any ill effects which I had traced to them, as
because they were not agreeable to my imagination. The repugnance to
animal food is not the effect of experience, but is an instinct. It
appeared more beautiful to live low and fare hard in many respects; and
though I never did so, I went far enough to please my imagination. I
believe that every man who has ever been earnest to preserve his higher
or poetic faculties in the best condition has been particularly
inclined to abstain from animal food, and from much food of any kind.
It is a significant fact, stated by entomologists, I find it in Kirby
and Spence, that “some insects in their perfect state, though furnished
with organs of feeding, make no use of them;” and they lay it down as
“a general rule, that almost all insects in this state eat much less
than in that of larvæ. The voracious caterpillar when transformed into
a butterfly,” . . “and the gluttonous maggot when become a fly,”
content themselves with a drop or two of honey or some other sweet
liquid. The abdomen under the wings of the butterfly still represents
the larva. This is the tid-bit which tempts his insectivorous fate. The
gross feeder is a man in the larva state; and there are whole nations
in that condition, nations without fancy or imagination, whose vast
abdomens betray them.

It is hard to provide and cook so simple and clean a diet as will not
offend the imagination; but this, I think, is to be fed when we feed
the body; they should both sit down at the same table. Yet perhaps this
may be done. The fruits eaten temperately need not make us ashamed of
our appetites, nor interrupt the worthiest pursuits. But put an extra
condiment into your dish, and it will poison you. It is not worth the
while to live by rich cookery. Most men would feel shame if caught
preparing with their own hands precisely such a dinner, whether of
animal or vegetable food, as is every day prepared for them by others.
Yet till this is otherwise we are not civilized, and, if gentlemen and
ladies, are not true men and women. This certainly suggests what change
is to be made. It may be vain to ask why the imagination will not be
reconciled to flesh and fat. I am satisfied that it is not. Is it not a
reproach that man is a carnivorous animal? True, he can and does live,
in a great measure, by preying on other animals; but this is a
miserable way,—as any one who will go to snaring rabbits, or
slaughtering lambs, may learn,—and he will be regarded as a benefactor
of his race who shall teach man to confine himself to a more innocent
and wholesome diet. Whatever my own practice may be, I have no doubt
that it is a part of the destiny of the human race, in its gradual
improvement, to leave off eating animals, as surely as the savage
tribes have left off eating each other when they came in contact with
the more civilized.

If one listens to the faintest but constant suggestions of his genius,
which are certainly true, he sees not to what extremes, or even
insanity, it may lead him; and yet that way, as he grows more resolute
and faithful, his road lies. The faintest assured objection which one
healthy man feels will at length prevail over the arguments and customs
of mankind. No man ever followed his genius till it misled him. Though
the result were bodily weakness, yet perhaps no one can say that the
consequences were to be regretted, for these were a life in conformity
to higher principles. If the day and the night are such that you greet
them with joy, and life emits a fragrance like flowers and
sweet-scented herbs, is more elastic, more starry, more immortal,—that
is your success. All nature is your congratulation, and you have cause
momentarily to bless yourself. The greatest gains and values are
farthest from being appreciated. We easily come to doubt if they exist.
We soon forget them. They are the highest reality. Perhaps the facts
most astounding and most real are never communicated by man to man. The
true harvest of my daily life is somewhat as intangible and
indescribable as the tints of morning or evening. It is a little
star-dust caught, a segment of the rainbow which I have clutched.

Yet, for my part, I was never unusually squeamish; I could sometimes
eat a fried rat with a good relish, if it were necessary. I am glad to
have drunk water so long, for the same reason that I prefer the natural
sky to an opium-eater’s heaven. I would fain keep sober always; and
there are infinite degrees of drunkenness. I believe that water is the
only drink for a wise man; wine is not so noble a liquor; and think of
dashing the hopes of a morning with a cup of warm coffee, or of an
evening with a dish of tea! Ah, how low I fall when I am tempted by
them! Even music may be intoxicating. Such apparently slight causes
destroyed Greece and Rome, and will destroy England and America. Of all
ebriosity, who does not prefer to be intoxicated by the air he
breathes? I have found it to be the most serious objection to coarse
labors long continued, that they compelled me to eat and drink coarsely
also. But to tell the truth, I find myself at present somewhat less
particular in these respects. I carry less religion to the table, ask
no blessing; not because I am wiser than I was, but, I am obliged to
confess, because, however much it is to be regretted, with years I have
grown more coarse and indifferent. Perhaps these questions are
entertained only in youth, as most believe of poetry. My practice is
“nowhere,” my opinion is here. Nevertheless I am far from regarding
myself as one of those privileged ones to whom the Ved refers when it
says, that “he who has true faith in the Omnipresent Supreme Being may
eat all that exists,” that is, is not bound to inquire what is his
food, or who prepares it; and even in their case it is to be observed,
as a Hindoo commentator has remarked, that the Vedant limits this
privilege to “the time of distress.”

Who has not sometimes derived an inexpressible satisfaction from his
food in which appetite had no share? I have been thrilled to think that
I owed a mental perception to the commonly gross sense of taste, that I
have been inspired through the palate, that some berries which I had
eaten on a hill-side had fed my genius. “The soul not being mistress of
herself,” says Thseng-tseu, “one looks, and one does not see; one
listens, and one does not hear; one eats, and one does not know the
savor of food.” He who distinguishes the true savor of his food can
never be a glutton; he who does not cannot be otherwise. A puritan may
go to his brown-bread crust with as gross an appetite as ever an
alderman to his turtle. Not that food which entereth into the mouth
defileth a man, but the appetite with which it is eaten. It is neither
the quality nor the quantity, but the devotion to sensual savors; when
that which is eaten is not a viand to sustain our animal, or inspire
our spiritual life, but food for the worms that possess us. If the
hunter has a taste for mud-turtles, muskrats, and other such savage
tid-bits, the fine lady indulges a taste for jelly made of a calf’s
foot, or for sardines from over the sea, and they are even. He goes to
the mill-pond, she to her preserve-pot. The wonder is how they, how you
and I, can live this slimy, beastly life, eating and drinking.

Our whole life is startlingly moral. There is never an instant’s truce
between virtue and vice. Goodness is the only investment that never
fails. In the music of the harp which trembles round the world it is
the insisting on this which thrills us. The harp is the travelling
patterer for the Universe’s Insurance Company, recommending its laws,
and our little goodness is all the assessment that we pay. Though the
youth at last grows indifferent, the laws of the universe are not
indifferent, but are forever on the side of the most sensitive. Listen
to every zephyr for some reproof, for it is surely there, and he is
unfortunate who does not hear it. We cannot touch a string or move a
stop but the charming moral transfixes us. Many an irksome noise, go a
long way off, is heard as music, a proud sweet satire on the meanness
of our lives.

We are conscious of an animal in us, which awakens in proportion as our
higher nature slumbers. It is reptile and sensual, and perhaps cannot
be wholly expelled; like the worms which, even in life and health,
occupy our bodies. Possibly we may withdraw from it, but never change
its nature. I fear that it may enjoy a certain health of its own; that
we may be well, yet not pure. The other day I picked up the lower jaw
of a hog, with white and sound teeth and tusks, which suggested that
there was an animal health and vigor distinct from the spiritual. This
creature succeeded by other means than temperance and purity. “That in
which men differ from brute beasts,” says Mencius, “is a thing very
inconsiderable; the common herd lose it very soon; superior men
preserve it carefully.” Who knows what sort of life would result if we
had attained to purity? If I knew so wise a man as could teach me
purity I would go to seek him forthwith. “A command over our passions,
and over the external senses of the body, and good acts, are declared
by the Ved to be indispensable in the mind’s approximation to God.” Yet
the spirit can for the time pervade and control every member and
function of the body, and transmute what in form is the grossest
sensuality into purity and devotion. The generative energy, which, when
we are loose, dissipates and makes us unclean, when we are continent
invigorates and inspires us. Chastity is the flowering of man; and what
are called Genius, Heroism, Holiness, and the like, are but various
fruits which succeed it. Man flows at once to God when the channel of
purity is open. By turns our purity inspires and our impurity casts us
down. He is blessed who is assured that the animal is dying out in him
day by day, and the divine being established. Perhaps there is none but
has cause for shame on account of the inferior and brutish nature to
which he is allied. I fear that we are such gods or demigods only as
fauns and satyrs, the divine allied to beasts, the creatures of
appetite, and that, to some extent, our very life is our disgrace.—

     “How happy’s he who hath due place assigned
     To his beasts and disafforested his mind!
                *    *    *    *    *
     Can use this horse, goat, wolf, and ev’ry beast,
     And is not ass himself to all the rest!
     Else man not only is the herd of swine,
     But he’s those devils too which did incline
     Them to a headlong rage, and made them worse.”

All sensuality is one, though it takes many forms; all purity is one.
It is the same whether a man eat, or drink, or cohabit, or sleep
sensually. They are but one appetite, and we only need to see a person
do any one of these things to know how great a sensualist he is. The
impure can neither stand nor sit with purity. When the reptile is
attacked at one mouth of his burrow, he shows himself at another. If
you would be chaste, you must be temperate. What is chastity? How shall
a man know if he is chaste? He shall not know it. We have heard of this
virtue, but we know not what it is. We speak conformably to the rumor
which we have heard. From exertion come wisdom and purity; from sloth
ignorance and sensuality. In the student sensuality is a sluggish habit
of mind. An unclean person is universally a slothful one, one who sits
by a stove, whom the sun shines on prostrate, who reposes without being
fatigued. If you would avoid uncleanness, and all the sins, work
earnestly, though it be at cleaning a stable. Nature is hard to be
overcome, but she must be overcome. What avails it that you are
Christian, if you are not purer than the heathen, if you deny yourself
no more, if you are not more religious? I know of many systems of
religion esteemed heathenish whose precepts fill the reader with shame,
and provoke him to new endeavors, though it be to the performance of
rites merely.

I hesitate to say these things, but it is not because of the subject,—I
care not how obscene my _words_ are,—but because I cannot speak of them
without betraying my impurity. We discourse freely without shame of one
form of sensuality, and are silent about another. We are so degraded
that we cannot speak simply of the necessary functions of human nature.
In earlier ages, in some countries, every function was reverently
spoken of and regulated by law. Nothing was too trivial for the Hindoo
lawgiver, however offensive it may be to modern taste. He teaches how
to eat, drink, cohabit, void excrement and urine, and the like,
elevating what is mean, and does not falsely excuse himself by calling
these things trifles.

Every man is the builder of a temple, called his body, to the god he
worships, after a style purely his own, nor can he get off by hammering
marble instead. We are all sculptors and painters, and our material is
our own flesh and blood and bones. Any nobleness begins at once to
refine a man’s features, any meanness or sensuality to imbrute them.

John Farmer sat at his door one September evening, after a hard day’s
work, his mind still running on his labor more or less. Having bathed,
he sat down to re-create his intellectual man. It was a rather cool
evening, and some of his neighbors were apprehending a frost. He had
not attended to the train of his thoughts long when he heard some one
playing on a flute, and that sound harmonized with his mood. Still he
thought of his work; but the burden of his thought was, that though
this kept running in his head, and he found himself planning and
contriving it against his will, yet it concerned him very little. It
was no more than the scurf of his skin, which was constantly shuffled
off. But the notes of the flute came home to his ears out of a
different sphere from that he worked in, and suggested work for certain
faculties which slumbered in him. They gently did away with the street,
and the village, and the state in which he lived. A voice said to
him,—Why do you stay here and live this mean moiling life, when a
glorious existence is possible for you? Those same stars twinkle over
other fields than these.—But how to come out of this condition and
actually migrate thither? All that he could think of was to practise
some new austerity, to let his mind descend into his body and redeem
it, and treat himself with ever increasing respect.


